Replace runtest --cts option with more generic --suite option.

This will allow you to run a the set of test_defs with attribute suite="foo"
like this:
  runtest --suite foo

Bug 2401250
diff --git a/testrunner/test_defs/test_defs.py b/testrunner/test_defs/test_defs.py
index 6d885fa..c305620 100644
--- a/testrunner/test_defs/test_defs.py
+++ b/testrunner/test_defs/test_defs.py
@@ -109,13 +109,9 @@
         con_tests.append(test)
     return con_tests
 
-  def GetCtsTests(self):
-    """Return list of cts tests."""
-    cts_tests = []
-    for test in self.GetTests():
-      if test.IsCts():
-        cts_tests.append(test)
-    return cts_tests
+  def GetTestsInSuite(self, suite):
+    """Return list of tests in given suite."""
+    return [t for t in self.GetTests() if t.GetSuite() == suite]
 
   def GetTest(self, name):
     return self._testname_map.get(name, None)